@@ -1,11 +1,18 @@
 package POEx::IRC::Backend::Connect;
-$POEx::IRC::Backend::Connect::VERSION = '0.025001';
+$POEx::IRC::Backend::Connect::VERSION = '0.026001';
 use Carp;
 use Types::Standard -all;
 
 use Moo; use MooX::late;
 with 'POEx::IRC::Backend::Role::HasWheel';
 
+has args => (
+  lazy      => 1,
+  is        => 'ro',
+  predicate => 1,
+  default   => sub { +{} },
+);
+
 has alarm_id => (
   ## Idle alarm ID.
   lazy      => 1,
@@ -125,7 +132,7 @@ has sockport => (
 
 =head1 NAME
 
-POEx::IRC::Backend::Connect - A connectoed socket wheel
+POEx::IRC::Backend::Connect - A connected IRC socket
 
 =head1 SYNOPSIS
 
@@ -144,10 +151,18 @@ attributes:
 =head2 alarm_id
 
 Connected socket wheels normally have a POE alarm ID attached for an idle 
-timer. Writable attribute.
+timer. This attribute is writable.
 
 Predicate: B<has_alarm_id>
 
+=head2 args
+
+Arbitrary metadata attached to this connection; by default, any C<args>
+attached to a L<POEx::IRC::Backend::Connector> that spawns a
+L<POEx::IRC::Backend::Connect> are passed along.
+
+Predicate: B<has_args>
+
 =head2 compressed
 
 Set to true if the Zlib filter has been added.
