@@ -1,18 +1,19 @@
 package POEx::IRC::Backend::Connector;
-$POEx::IRC::Backend::Connector::VERSION = '0.025001';
+$POEx::IRC::Backend::Connector::VERSION = '0.026001';
 use Moo;
 with 'POEx::IRC::Backend::Role::Connector';
 
 has args => (
-  lazy    => 1,
-  is      => 'ro',
-  default => sub { {} },
+  lazy      => 1,
+  is        => 'ro',
+  predicate => 1,
+  default   => sub { +{} },
 );
 
 has bindaddr => (
   lazy      => 1,
   is        => 'ro',
-  predicate => 'has_bindaddr',
+  predicate => 1,
   default   => sub { '' },
 );
 
@@ -24,7 +25,7 @@ has bindaddr => (
 
 =head1 NAME
 
-POEx::IRC::Backend::Connector - An outgoing connector
+POEx::IRC::Backend::Connector - An outgoing IRC socket connector
 
 =head1 SYNOPSIS
 
@@ -42,13 +43,17 @@ following attributes:
 
 The local address this Connector should bind to.
 
-B<has_bindaddr> can be used to find out if we have a local bind address
-specified.
+Predicate: B<has_bindaddr>
 
 =head2 args
 
 Arbitrary metadata attached to this Connector. (By default, this is a HASH.)
 
+This is typically passed on to a successfully spawned
+L<POEx::IRC::Backend::Connect>.
+
+Predicate: B<has_args>
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
